# simple plotting + fitting
Doc: https://apn-pucky.github.io/smpl/index.html

| [Stable](https://apn-pucky.github.io/smpl/index.html)        | [Test](https://apn-pucky.github.io/smpl/test/index.html)           |
| ------------- |:-------------:|
| [![PyPI version](https://badge.fury.io/py/smpl.svg)](https://badge.fury.io/py/smpl)      | - | 
| ![workflow](https://github.com/APN-Pucky/smpl/actions/workflows/release.yml/badge.svg)      | [![test](https://github.com/APN-Pucky/smpl/actions/workflows/test.yml/badge.svg)](https://github.com/APN-Pucky/smpl/actions/workflows/test.yml)     |
| ![downloads](https://img.shields.io/pypi/dm/smpl.svg) | -     |
| [![Codacy Badge](https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2)](https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade) | -      |
| [![Codacy Badge](https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2)](https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage) | -      |
| [![Coverage Status](https://coveralls.io/repos/github/APN-Pucky/smpl/badge.svg?branch=master)](https://coveralls.io/github/APN-Pucky/smpl?branch=stable) | [![Coverage Status](https://coveralls.io/repos/github/APN-Pucky/smpl/badge.svg?branch=test)](https://coveralls.io/github/APN-Pucky/smpl?branch=test) |

## Versions

### stable
```sh
pip install smpl
```
Optional: --user or --upgrade

### test
```sh
pip install --index-url https://test.pypi.org/simple/ smpl
```
